@@ -439,7 +439,7 @@ void Kopete::ChatSession::addContact( const Kopete::Contact *c, const Kopete::On
 void Kopete::ChatSession::addContact( const Kopete::Contact *c, bool suppress )
 {
 	//kDebug( 14010 ) ;
-	if ( d->contacts.contains( (Kopete::Contact*)(Kopete::Contact*)(Kopete::Contact*)(Kopete::Contact*)(Kopete::Contact*)(Kopete::Contact*)(Kopete::Contact*)(Kopete::Contact*)(Kopete::Contact*)c ) )
+	if ( d->contacts.contains( (Kopete::Contact*)c ) )
 	{
 		kDebug( 14010 ) << "Contact already exists";
 //		emit contactAdded( c, suppress );
@@ -456,7 +456,8 @@ void Kopete::ChatSession::addContact( const Kopete::Contact *c, bool suppress )
 			d->contacts.append( (Kopete::Contact*)c );
 
 			disconnect( old, SIGNAL(onlineStatusChanged(Kopete::Contact*,Kopete::OnlineStatus,Kopete::OnlineStatus)),
-			this, SLOT(slotOnlineStatusChanged(Kopete::Contact*,Kopete::OnlineStatus,Kopete::OnlineStatus)) );
+				this, SLOT(slotOnlineStatusChanged(Kopete::Contact*,Kopete::OnlineStatus,Kopete::OnlineStatus)) );
+			disconnect( old, SIGNAL(statusMessageChanged(Kopete::Contact*)), this, SIGNAL(statusMessageChanged(Kopete::Contact*)) );
 
 			if ( old->metaContact() )
 			{
@@ -479,7 +480,8 @@ void Kopete::ChatSession::addContact( const Kopete::Contact *c, bool suppress )
 
 		connect( c, SIGNAL(onlineStatusChanged(Kopete::Contact*,Kopete::OnlineStatus,Kopete::OnlineStatus)),
 			this, SLOT(slotOnlineStatusChanged(Kopete::Contact*,Kopete::OnlineStatus,Kopete::OnlineStatus)) );
-;
+		connect( c, SIGNAL(statusMessageChanged(Kopete::Contact*)), this, SIGNAL(statusMessageChanged(Kopete::Contact*)) );
+
 		if ( c->metaContact() )
 		{
 			connect( c->metaContact(), SIGNAL(displayNameChanged(QString,QString)), this, SLOT(slotUpdateDisplayName()) );
